@@ -13,5 +13,9 @@
 #'
 #' bp_lengths(list(1:3, 2))
 lengths = function(x, use.names = TRUE) {
-  vapply(x, length, FUN.VALUE = NA_integer_, USE.NAMES = use.names)
+  ans <- sapply(x, length, USE.NAMES = FALSE)
+  if (!isTRUE(use.names)) {
+    names(ans) <- NULL
+  }
+  ans
 }
